
**kirUI** is a framework for building user interfaces.

Issues
======
- Ha a modal nincs nyitva, de a szerver 200-as válasszal tér vissza, akkor a modal link egy csúnya hibát dob. Jó lenne figyelmeztetni a felhasználót, hogy a backenden 403-mmal kell visszatérni.